AttErrorCode

Struct AttErrorCode 

pub struct AttErrorCode { /* private fields */ }
Attribute Error Code

This enum type describes the ATT_ERROR_RSP PDU from the Bluetooth Core Specification Version 6.0 | Vol 3, Part F (page 1491) See also: Core Specification Supplement, Part B: Common Profile and Service Error Codes

Implementations

Source

impl AttErrorCode

pub const INVALID_HANDLE: Self

Attempted to use a handle that isn’t valid on this server

pub const READ_NOT_PERMITTED: Self

The attribute cannot be read

pub const WRITE_NOT_PERMITTED: Self

The attribute cannot be written due to permissions

pub const INVALID_PDU: Self

The attribute PDU was invalid

pub const INSUFFICIENT_AUTHENTICATION: Self

The attribute requires authentication before it can be read or written

pub const REQUEST_NOT_SUPPORTED: Self

ATT Server does not support the request received from the client

pub const INVALID_OFFSET: Self

Offset specified was past the end of the attribute

pub const INSUFFICIENT_AUTHORISATION: Self

The attribute requires authorisation before it can be read or written

pub const PREPARE_QUEUE_FULL: Self

Too many prepare writes have been queued

pub const ATTRIBUTE_NOT_FOUND: Self

No attribute found within the given attribute handle range

pub const ATTRIBUTE_NOT_LONG: Self

The attribute cannot be read using the ATT_READ_BLOB_REQ PDU

pub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: Self

The Encryption Key Size used for encrypting this link is too short

pub const INVALID_ATTRIBUTE_VALUE_LENGTH: Self

The attribute value length is invalid for the operation

pub const UNLIKELY_ERROR: Self

The attribute request that was requested had encountered an error that was unlikely, and therefore could not be completed as requested

pub const INSUFFICIENT_ENCRYPTION: Self

The attribute requires encryption before it can be read or written

pub const UNSUPPORTED_GROUP_TYPE: Self

The attribute type is not a supported grouping attribute as defined by a higher layer specification

pub const INSUFFICIENT_RESOURCES: Self

Insufficient Resources to complete the request

pub const DATABASE_OUT_OF_SYNC: Self

The server requests the client to rediscover the database

pub const VALUE_NOT_ALLOWED: Self

The attribute parameter value was not allowed

pub const WRITE_REQUEST_REJECTED: Self

Common profile and service error codes The write request could not be fulfilled for reasons other than permissions

pub const CCCD_IMPROPERLY_CONFIGURED: Self

The client characteristic configuration descriptor (CCCD) is not configured according to the requirements of the profile or service

pub const PROCEDURE_ALREADY_IN_PROGRESS: Self

The profile or service request could not be serviced because an operation that has been previousl triggered is still in progress

pub const OUT_OF_RANGE: Self

The attribute value is out of range as defined by a profile or service specification

pub const fn new(value: u8) -> Self

Create a new error code from a raw value

pub const fn to_u8(self) -> u8

Get the raw value of this error code