pub struct AttErrorCode { /* private fields */ }Expand description
Attribute Error Code
This enum type describes the ATT_ERROR_RSP PDU from the Bluetooth Core Specification
Version 6.0 | Vol 3, Part F (page 1491)
See also: Core Specification Supplement, Part B: Common Profile and Service Error Codes
Implementations
Sourceimpl AttErrorCode
impl AttErrorCode
Sourcepub const INVALID_HANDLE: Self
pub const INVALID_HANDLE: Self
Attempted to use a handle that isn’t valid on this server
Sourcepub const READ_NOT_PERMITTED: Self
pub const READ_NOT_PERMITTED: Self
The attribute cannot be read
Sourcepub const WRITE_NOT_PERMITTED: Self
pub const WRITE_NOT_PERMITTED: Self
The attribute cannot be written due to permissions
Sourcepub const INVALID_PDU: Self
pub const INVALID_PDU: Self
The attribute PDU was invalid
Sourcepub const INSUFFICIENT_AUTHENTICATION: Self
pub const INSUFFICIENT_AUTHENTICATION: Self
The attribute requires authentication before it can be read or written
Sourcepub const REQUEST_NOT_SUPPORTED: Self
pub const REQUEST_NOT_SUPPORTED: Self
ATT Server does not support the request received from the client
Sourcepub const INVALID_OFFSET: Self
pub const INVALID_OFFSET: Self
Offset specified was past the end of the attribute
Sourcepub const INSUFFICIENT_AUTHORISATION: Self
pub const INSUFFICIENT_AUTHORISATION: Self
The attribute requires authorisation before it can be read or written
Sourcepub const PREPARE_QUEUE_FULL: Self
pub const PREPARE_QUEUE_FULL: Self
Too many prepare writes have been queued
Sourcepub const ATTRIBUTE_NOT_FOUND: Self
pub const ATTRIBUTE_NOT_FOUND: Self
No attribute found within the given attribute handle range
Sourcepub const ATTRIBUTE_NOT_LONG: Self
pub const ATTRIBUTE_NOT_LONG: Self
The attribute cannot be read using the ATT_READ_BLOB_REQ PDU
Sourcepub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: Self
pub const INSUFFICIENT_ENCRYPTION_KEY_SIZE: Self
The Encryption Key Size used for encrypting this link is too short
Sourcepub const INVALID_ATTRIBUTE_VALUE_LENGTH: Self
pub const INVALID_ATTRIBUTE_VALUE_LENGTH: Self
The attribute value length is invalid for the operation
Sourcepub const UNLIKELY_ERROR: Self
pub const UNLIKELY_ERROR: Self
The attribute request that was requested had encountered an error that was unlikely, and therefore could not be completed as requested
Sourcepub const INSUFFICIENT_ENCRYPTION: Self
pub const INSUFFICIENT_ENCRYPTION: Self
The attribute requires encryption before it can be read or written
Sourcepub const UNSUPPORTED_GROUP_TYPE: Self
pub const UNSUPPORTED_GROUP_TYPE: Self
The attribute type is not a supported grouping attribute as defined by a higher layer specification
Sourcepub const INSUFFICIENT_RESOURCES: Self
pub const INSUFFICIENT_RESOURCES: Self
Insufficient Resources to complete the request
Sourcepub const DATABASE_OUT_OF_SYNC: Self
pub const DATABASE_OUT_OF_SYNC: Self
The server requests the client to rediscover the database
Sourcepub const VALUE_NOT_ALLOWED: Self
pub const VALUE_NOT_ALLOWED: Self
The attribute parameter value was not allowed
Sourcepub const WRITE_REQUEST_REJECTED: Self
pub const WRITE_REQUEST_REJECTED: Self
Common profile and service error codes The write request could not be fulfilled for reasons other than permissions
Sourcepub const CCCD_IMPROPERLY_CONFIGURED: Self
pub const CCCD_IMPROPERLY_CONFIGURED: Self
The client characteristic configuration descriptor (CCCD) is not configured according to the requirements of the profile or service
Sourcepub const PROCEDURE_ALREADY_IN_PROGRESS: Self
pub const PROCEDURE_ALREADY_IN_PROGRESS: Self
The profile or service request could not be serviced because an operation that has been previousl triggered is still in progress
Sourcepub const OUT_OF_RANGE: Self
pub const OUT_OF_RANGE: Self
The attribute value is out of range as defined by a profile or service specification